"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const helper_1 = require("./helper");
const typescript_ilogger_1 = require("typescript-ilogger");
const test_values_1 = require("./test-values");
const eventSourceMappingConfigurationResponse = {};
const invocationResponseResponse = {};
const invokeAsyncResponseResponse = {};
const listEventSourceMappingsResponseResponse = {};
const getEventSourceMapping = jest.fn().mockImplementation(() => {
    return Promise.resolve(eventSourceMappingConfigurationResponse);
});
const invoke = jest.fn().mockImplementation(() => {
    return Promise.resolve(invocationResponseResponse);
});
const invokeAsync = jest.fn().mockImplementation(() => {
    return Promise.resolve(invokeAsyncResponseResponse);
});
const listEventSourceMappings = jest.fn().mockImplementation(() => {
    return Promise.resolve(listEventSourceMappingsResponseResponse);
});
const updateEventSourceMapping = jest.fn().mockImplementation(() => {
    return Promise.resolve(eventSourceMappingConfigurationResponse);
});
jest.mock('@aws-sdk/client-lambda', () => {
    return {
        Lambda: jest.fn().mockImplementation(() => {
            return {
                getEventSourceMapping,
                invoke,
                invokeAsync,
                listEventSourceMappings,
                updateEventSourceMapping,
            };
        }),
    };
});
const logger = new typescript_ilogger_1.Logger(typescript_ilogger_1.LogLevel.Off);
const lambdaHelperMock = new helper_1.LambdaHelper(logger);
const TestValues = new test_values_1.TestingValues();
describe(`${helper_1.LambdaHelper.name}.${lambdaHelperMock.DisableDynamoEventSourceMappingAsync.name}`, () => {
    const action = `${helper_1.LambdaHelper.name}.${lambdaHelperMock.UpdateEventSourceMappingAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} functionName`, () => {
        const actual = lambdaHelperMock.DisableDynamoEventSourceMappingAsync(TestValues.EmptyString, TestValues.Uuid);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} functionName`);
    });
    test(`${TestValues.ThrowsOnEmpty} uuid`, () => {
        const actual = lambdaHelperMock.DisableDynamoEventSourceMappingAsync(TestValues.Name, TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} uuid`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = lambdaHelperMock.DisableDynamoEventSourceMappingAsync(TestValues.Name, TestValues.Uuid);
        return expect(actual).resolves.toEqual(eventSourceMappingConfigurationResponse);
    });
});
describe(`${helper_1.LambdaHelper.name}.${lambdaHelperMock.DisableKinesisEventSourceMappingAsync.name}`, () => {
    const action = `${helper_1.LambdaHelper.name}.${lambdaHelperMock.UpdateEventSourceMappingAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} functionName`, () => {
        const actual = lambdaHelperMock.DisableKinesisEventSourceMappingAsync(TestValues.EmptyString, TestValues.Uuid);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} functionName`);
    });
    test(`${TestValues.ThrowsOnEmpty} uuid`, () => {
        const actual = lambdaHelperMock.DisableKinesisEventSourceMappingAsync(TestValues.Name, TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} uuid`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = lambdaHelperMock.DisableKinesisEventSourceMappingAsync(TestValues.Name, TestValues.Uuid);
        return expect(actual).resolves.toEqual(eventSourceMappingConfigurationResponse);
    });
});
describe(`${helper_1.LambdaHelper.name}.${lambdaHelperMock.DisableSQSEventSourceMappingAsync.name}`, () => {
    const action = `${helper_1.LambdaHelper.name}.${lambdaHelperMock.UpdateEventSourceMappingAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} functionName`, () => {
        const actual = lambdaHelperMock.DisableSQSEventSourceMappingAsync(TestValues.EmptyString, TestValues.Uuid);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} functionName`);
    });
    test(`${TestValues.ThrowsOnEmpty} uuid`, () => {
        const actual = lambdaHelperMock.DisableSQSEventSourceMappingAsync(TestValues.Name, TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} uuid`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = lambdaHelperMock.DisableSQSEventSourceMappingAsync(TestValues.Name, TestValues.Uuid);
        return expect(actual).resolves.toEqual(eventSourceMappingConfigurationResponse);
    });
});
describe(`${helper_1.LambdaHelper.name}.${lambdaHelperMock.EnableDynamoEventSourceMappingAsync.name}`, () => {
    const action = `${helper_1.LambdaHelper.name}.${lambdaHelperMock.UpdateEventSourceMappingAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} functionName`, () => {
        const actual = lambdaHelperMock.EnableDynamoEventSourceMappingAsync(TestValues.EmptyString, TestValues.Uuid);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} functionName`);
    });
    test(`${TestValues.ThrowsOnEmpty} uuid`, () => {
        const actual = lambdaHelperMock.EnableDynamoEventSourceMappingAsync(TestValues.Name, TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} uuid`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = lambdaHelperMock.EnableDynamoEventSourceMappingAsync(TestValues.Name, TestValues.Uuid);
        return expect(actual).resolves.toEqual(eventSourceMappingConfigurationResponse);
    });
});
describe(`${helper_1.LambdaHelper.name}.${lambdaHelperMock.EnableKinesisEventSourceMappingAsync.name}`, () => {
    const action = `${helper_1.LambdaHelper.name}.${lambdaHelperMock.UpdateEventSourceMappingAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} functionName`, () => {
        const actual = lambdaHelperMock.EnableKinesisEventSourceMappingAsync(TestValues.EmptyString, TestValues.Uuid);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} functionName`);
    });
    test(`${TestValues.ThrowsOnEmpty} uuid`, () => {
        const actual = lambdaHelperMock.EnableKinesisEventSourceMappingAsync(TestValues.Name, TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} uuid`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = lambdaHelperMock.EnableKinesisEventSourceMappingAsync(TestValues.Name, TestValues.Uuid);
        return expect(actual).resolves.toEqual(eventSourceMappingConfigurationResponse);
    });
});
describe(`${helper_1.LambdaHelper.name}.${lambdaHelperMock.EnableSQSEventSourceMappingAsync.name}`, () => {
    const action = `${helper_1.LambdaHelper.name}.${lambdaHelperMock.UpdateEventSourceMappingAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} functionName`, () => {
        const actual = lambdaHelperMock.EnableSQSEventSourceMappingAsync(TestValues.EmptyString, TestValues.Uuid);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} functionName`);
    });
    test(`${TestValues.ThrowsOnEmpty} uuid`, () => {
        const actual = lambdaHelperMock.EnableSQSEventSourceMappingAsync(TestValues.Name, TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} uuid`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = lambdaHelperMock.EnableSQSEventSourceMappingAsync(TestValues.Name, TestValues.Uuid);
        return expect(actual).resolves.toEqual(eventSourceMappingConfigurationResponse);
    });
});
describe(`${helper_1.LambdaHelper.name}.${lambdaHelperMock.GetEventSourceMappingAsync.name}`, () => {
    const action = `${helper_1.LambdaHelper.name}.${lambdaHelperMock.GetEventSourceMappingAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} uuid`, () => {
        const actual = lambdaHelperMock.GetEventSourceMappingAsync(TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} uuid`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = lambdaHelperMock.GetEventSourceMappingAsync(TestValues.Uuid);
        return expect(actual).resolves.toEqual(eventSourceMappingConfigurationResponse);
    });
});
describe(`${helper_1.LambdaHelper.name}.${lambdaHelperMock.ListEventSourceMappingsAsync.name}`, () => {
    const action = `${helper_1.LambdaHelper.name}.${lambdaHelperMock.ListEventSourceMappingsAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} functionName`, () => {
        const actual = lambdaHelperMock.ListEventSourceMappingsAsync(TestValues.EmptyString, TestValues.Arn);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} functionName`);
    });
    test(`${TestValues.ThrowsOnEmpty} eventSourceArn`, () => {
        const actual = lambdaHelperMock.ListEventSourceMappingsAsync(TestValues.Name, TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} eventSourceArn`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = lambdaHelperMock.ListEventSourceMappingsAsync(TestValues.Name, TestValues.Arn);
        return expect(actual).resolves.toEqual(listEventSourceMappingsResponseResponse);
    });
});
describe(`${helper_1.LambdaHelper.name}.${lambdaHelperMock.InvokeSync.name}`, () => {
    const action = `${helper_1.LambdaHelper.name}.${lambdaHelperMock.InvokeSync.name}`;
    test(`${TestValues.ThrowsOnEmpty} functionName`, () => {
        const actual = lambdaHelperMock.InvokeSync(TestValues.EmptyString, TestValues.Body);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} functionName`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = lambdaHelperMock.InvokeSync(TestValues.Name, TestValues.Body);
        return expect(actual).resolves.toEqual(invocationResponseResponse);
    });
});
describe(`${helper_1.LambdaHelper.name}.${lambdaHelperMock.InvokeAsync.name}`, () => {
    const action = `${helper_1.LambdaHelper.name}.${lambdaHelperMock.InvokeAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} functionName`, () => {
        const actual = lambdaHelperMock.InvokeAsync(TestValues.EmptyString, TestValues.Body);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} functionName`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = lambdaHelperMock.InvokeAsync(TestValues.Name, TestValues.Body);
        return expect(actual).resolves.toEqual(invocationResponseResponse);
    });
});
describe(`${helper_1.LambdaHelper.name}.${lambdaHelperMock.UpdateEventSourceMappingAsync.name}`, () => {
    const action = `${helper_1.LambdaHelper.name}.${lambdaHelperMock.UpdateEventSourceMappingAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} functionName`, () => {
        const actual = lambdaHelperMock.UpdateEventSourceMappingAsync(TestValues.EmptyString, TestValues.BooleanValue, TestValues.Uuid, TestValues.NumberValue);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} functionName`);
    });
    test(`${TestValues.ThrowsOnEmpty} uuid`, () => {
        const actual = lambdaHelperMock.UpdateEventSourceMappingAsync(TestValues.Name, TestValues.BooleanValue, TestValues.EmptyString, TestValues.NumberValue);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} uuid`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = lambdaHelperMock.UpdateEventSourceMappingAsync(TestValues.Name, TestValues.BooleanValue, TestValues.Uuid, TestValues.NumberValue);
        return expect(actual).resolves.toEqual(eventSourceMappingConfigurationResponse);
    });
});
//# sourceMappingURL=helper-resolves.spec.js.map